@@ -1,6 +1,5 @@
 import logging
 
-from flatpaksync.flatpakcmd import flatpakcmd
 from flatpaksync.commands.command import command
 from flatpaksync.configs.write import write as writeconfig
 from flatpaksync.configs.read import read as readconfig
@@ -16,12 +15,6 @@ class remove(command):
 
 
     def execute(self, repo, appid):
-
-        fp=flatpakcmd()
-        logging.debug("Flatpak installed: {}".format(fp.isInstalled()))
-        logging.debug(fp.getVersion())
-        logging.debug("Configuration file: {}".format(self.conf))
-
         
         config=readconfig(self.conf)
         if config.read():
